+ powerpc-suppress-modpost-warnings-for-references-from-the-toc.patch added to -mm tree

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



The patch titled
     powerpc: suppress modpost warnings for references from the .toc
has been added to the -mm tree.  Its filename is
     powerpc-suppress-modpost-warnings-for-references-from-the-toc.patch

*** Remember to use Documentation/SubmitChecklist when testing your code ***

See http://www.zip.com.au/~akpm/linux/patches/stuff/added-to-mm.txt to find
out what to do about this

------------------------------------------------------
Subject: powerpc: suppress modpost warnings for references from the .toc
From: Stephen Rothwell <sfr@xxxxxxxxxxxxxxxx>

We should do better here by effetively "dereferencing" references to the
.toc (or the .got2) section, but that is much harder.

Signed-off-by: Stephen Rothwell <sfr@xxxxxxxxxxxxxxxx>
Cc: Paul Mackerras <paulus@xxxxxxxxx>
Cc: Sam Ravnborg <sam@xxxxxxxxxxxx>
Signed-off-by: Andrew Morton <akpm@xxxxxxxxxxxxxxxxxxxx>
---

 scripts/mod/modpost.c |    5 ++++-
 1 files changed, 4 insertions(+), 1 deletion(-)

diff -puN scripts/mod/modpost.c~powerpc-suppress-modpost-warnings-for-references-from-the-toc scripts/mod/modpost.c
--- a/scripts/mod/modpost.c~powerpc-suppress-modpost-warnings-for-references-from-the-toc
+++ a/scripts/mod/modpost.c
@@ -865,9 +865,12 @@ static void warn_sec_mismatch(const char
 		return;
 
 	/* fromsec whitelist - without a valid 'before'
 	 * powerpc has a GOT table in .got2 section */
 	if (strcmp(fromsec, ".got2") == 0)
 		return;
+	if (strcmp(fromsec, ".toc") == 0)
+		return;
 
 	if (before && after) {
 		warn("%s(%s+0x%llx): Section mismatch: reference to %s:%s "
_

Patches currently in -mm which might be from sfr@xxxxxxxxxxxxxxxx are

origin.patch
powerpc-suppress-modpost-warnings-for-references-from-the-toc.patch
move-three-functions-that-are-only-needed-for.patch
introduce-config_virt_to_bus.patch

-
@@ -865,9 +865,12 @@ static void warn_sec_mismatch(const char
 
 	/* fromsec whitelist - without a valid 'before'
-	 * powerpc has a GOT table in .got2 section */
+	 * powerpc has a GOT table in .got2 section
+	 * and also a .toc section */
 	if (strcmp(fromsec, ".got2") == 0)
 		return;
To unsubscribe from this list: send the line "unsubscribe mm-commits" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html

[Index of Archives]     [Kernel Newbies FAQ]     [Kernel Archive]     [IETF Annouce]     [DCCP]     [Netdev]     [Networking]     [Security]     [Bugtraq]     [Photo]     [Yosemite]     [MIPS Linux]     [ARM Linux]     [Linux Security]     [Linux RAID]     [Linux SCSI]

  Powered by Linux